summaryrefslogtreecommitdiffstats
path: root/src/gui/Configuration.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/Configuration.hpp')
-rw-r--r--src/gui/Configuration.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/gui/Configuration.hpp b/src/gui/Configuration.hpp
index c3aec5fc..75c352e9 100644
--- a/src/gui/Configuration.hpp
+++ b/src/gui/Configuration.hpp
@@ -49,8 +49,8 @@ public:
void apply_settings();
- const std::string& patch_folder() { return _patch_folder; }
- void set_patch_folder(const std::string& f) { _patch_folder = f; }
+ const std::string& graph_folder() { return _graph_folder; }
+ void set_graph_folder(const std::string& f) { _graph_folder = f; }
uint32_t get_port_color(const Client::PortModel* p);
@@ -62,8 +62,8 @@ public:
private:
App& _app;
- /** Most recent patch folder shown in open dialog */
- std::string _patch_folder;
+ /** Most recent graph folder shown in open dialog */
+ std::string _graph_folder;
NameStyle _name_style;